@@ -9,12 +9,20 @@
 #include <weaver.h>
 #include <weaverlogger.h>
 
+#include <kdemacros.h>
 #include <tdeconfig.h>
 #include <tdeversion.h>
 #include <tdeimproxy.h>
 #include <tdepimmacros.h>
 
-#include <tdenetworkconnections.h>
+#ifdef __TDE_HAVE_TDEHWLIB
+# include <tdenetworkconnections.h>
+#else
+namespace TDENetworkConnectionStatus {
+    enum TDENetworkConnectionStatus {
+    };
+}
+#endif
 
 #include "kmailIface.h"
 #include "kmmsgbase.h"
@@ -527,7 +535,9 @@ private:
   TQString     mAddMessageLastFolder;
   KMFolder    *mAddMsgCurrentFolder;
 
+#ifdef __TDE_HAVE_TDEHWLIB
   TDEGlobalNetworkManager *mNetworkManager;
+#endif
 };
 
 #endif
