@@ -1,6 +1,6 @@
 /***************************************************************************
   copyright            : (C) 2006 by David Nolden
-  email                : david.nolden.tdevelop@art-master.de
+  email                : david.nolden.kdevelop@art-master.de
 ***************************************************************************/
 
 /***************************************************************************
