@@ -904,7 +904,12 @@ int TQGIFFormat::decode(TQImage& img, TQImageConsumer* consumer,
 		    sheight = newtop + newheight;
 
 		if (img.isNull()) {
-		    img.create(swidth, sheight, 32);
+		    if (!img.create(swidth, sheight, 32)) {
+			// Check if the attempt to create the image failed. If
+			// it did, the image is broken and we should give up.
+			state = Error;
+			return -1;
+		    }
 		    memset( img.bits(), 0, img.numBytes() );
 		    if (consumer) consumer->setSize(swidth, sheight);
 		}
@@ -1221,6 +1226,8 @@ void TQGIFFormat::fillRect(TQImage& img, int col, int row, int w, int h, TQRgb c
 
 void TQGIFFormat::nextY(TQImage& img, TQImageConsumer* consumer)
 {
+    if (out_of_bounds)
+        return;
     int my;
     switch (interlace) {
       case 0:
